@@ -10,6 +10,7 @@
  * Samuel Hocevar,     VIA, ECP, France <sam@via.ecp.fr>,     17/12/99
  * Damien Lucas,       VIA, ECP, France <nitrox@via.ecp.fr>,  30/05/01
  * Marc Ariberti,      VIA, ECP, France <marcari@via.ecp.fr>, 29/04/02
+ * Christophe Massiot, VIA, ECP, France <massiot@via.ecp.fr>, 30/05/02
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,22 +43,20 @@
  *   delays our read from the disk.
  */ 
  
+/* common stuff */
+#include "vlms.h"
+
 #ifdef LINUX
 #  include <net/if.h>
 #endif
 
-#include <netinet/in.h>
-
-/* common stuff */
-#include "vlms.h"
-
 /* TS parsing functions */
 #include "ts.h"
 /* PS/PES parsing functions */
 #include "ps.h"
 
 #define COPYRIGHT \
-"VideoLAN Mini Server - version 0.2.1 Onatopp - (c)1996-2000 VideoLAN\n"
+"VideoLAN Mini Server - version 0.2.3 Onatopp - (c)1996-2002 VideoLAN\n"
 
 #define VERSION \
 COPYRIGHT \
@@ -81,7 +80,7 @@ COPYRIGHT \
 "  -c [0-15]                choose audio channel\n" \
 "  -s [0-31]                choose subtitle channel\n" \
 "\n" \
-"  -l                       loops for ever\n" \
+"  -l, --loop               loops for ever\n" \
 "  -n nbloops               loops the playlist nbloops times\n" \
 "\n" \
 "  -h, --help               display this help and exit\n" \
@@ -93,6 +92,7 @@ COPYRIGHT \
 static const struct option longopts[] =
 {
     /*  name,               has_arg,    flag,   val */
+    {   "loop",             0,          0,      'l' },
     {   "version",          0,          0,      'v' },
     {   "help",             0,          0,      'h' },
     {   0,                  0,          0,      0 }
@@ -117,9 +117,14 @@ s64 GetTime(void)
  * ConvertPCRTime : extracts and converts the PCR time in microseconds
  ******************************************************************************/
 
-s64 ConvertPCRTime(file_ts_packet *pcr_buff)
+s64 ConvertPCRTime(file_ts_packet *_pcr_buff)
 {
-    return( (((((s64)U32_AT(((u8*)pcr_buff)+6)) << 1) | (((u8*)pcr_buff)[10] >> 7)) * 300) / 27 );
+    u8 * pcr_buff = (u8 *)_pcr_buff;
+    return((((s64)(pcr_buff[6]) << 25) |
+            ((s64)(pcr_buff[7]) << 17) |
+            ((s64)(pcr_buff[8]) << 9) |
+            ((s64)(pcr_buff[9]) << 1) |
+            ((s64)(pcr_buff[10]) >> 7)) * 300 / 27 );
 }
 
 /******************************************************************************
@@ -414,6 +419,7 @@ ssize_t safe_read( options_t *options, unsigned char *buf, int count )
             return ret;
 
         if( ret == 0 )
+        {
             /* zero means end of file */
             if( options->i_list_index )
             {
@@ -437,6 +443,7 @@ ssize_t safe_read( options_t *options, unsigned char *buf, int count )
                     file_next( options );
                 }
             }
+        }
 
         cnt += ret;
     }
@@ -465,6 +472,7 @@ int open_socket( struct s_options *options,
     {
         BuildInetAddr( remote_addr, options->host );
     }
+#ifdef LINUX
     else
     {
         int i_if_nb;
@@ -484,6 +492,7 @@ int open_socket( struct s_options *options,
         *remote_addr = net_descr.a_if[i_if_nb-1].sa_bcast_addr;
         free( net_descr.a_if );
     }
+#endif
 
     if( options->ttl != 0 ) 
     {
@@ -491,7 +500,7 @@ int open_socket( struct s_options *options,
         if( IN_CLASSD( ntohl( remote_addr->sin_addr.s_addr ) ) )
         {
             if( setsockopt( socket_fd, IPPROTO_IP, IP_MULTICAST_TTL, 
-                            &sockopt, sizeof(sockopt) ) < 0 )
+                            (void *)&sockopt, sizeof(sockopt) ) < 0 )
             {
                 err_sys( "IP_MULTICAST_TTL setsockopt TTL error" );
             }
@@ -499,7 +508,7 @@ int open_socket( struct s_options *options,
         else 
         {
             if( setsockopt( socket_fd, IPPROTO_IP, IP_TTL, 
-                            &sockopt, sizeof(sockopt) ) < 0 )
+                            (void *)&sockopt, sizeof(sockopt) ) < 0 )
             {
                 err_sys( "IP_TTL setsockopt TTL error" );
             }
@@ -508,7 +517,7 @@ int open_socket( struct s_options *options,
     
     sockopt = 1;
     if( setsockopt( socket_fd, SOL_SOCKET, SO_BROADCAST,
-                    &sockopt, sizeof(sockopt) ) < 0 )
+                    (void *)&sockopt, sizeof(sockopt) ) < 0 )
     {
         err_sys( "SO_BROADCAST setsockopt error" );
     }
